Charms.Reactive |badge|
-----------------------

.. |badge| image:: https://travis-ci.org/juju-solutions/charms.reactive.svg
    :target: https://travis-ci.org/juju-solutions/charms.reactive

This module serves as the basis for creating charms and relation
implementations using the reactive pattern.

The full documentation is available online at: https://charmsreactive.readthedocs.io/en/latest/


Usage
-----

The recommended way to develop a charm using Charms.Reactive is by leveraging
the `base layer`_ and `Juju Compose`_.  See `Building a Charm from Layers`_.


.. _base layer: https://git.launchpad.net/~bcsaller/charms/+source/basic/
.. _Juju Compose: https://github.com/bcsaller/juju-compose
.. _Building a Charm from Layers: https://jujucharms.com/docs/stable/authors-charm-building
